@@ -656,6 +656,9 @@ class Client(commandServer, encrypt, Desktop):
         """
         if not os.path.exists(userdir):
             try:
+                pdir = os.path.dirname(userdir)
+                if not os.path.exists(pdir):
+                    self.createUserDirectory(pdir, uid, gid)
                 os.mkdir(userdir)
                 os.chown(userdir, uid, gid)
                 os.chmod(userdir, 0700)
@@ -962,6 +965,11 @@ class Client(commandServer, encrypt, Desktop):
                 if (result and removeEmpty and path.exists(resourcePath) and
                         not listDirectory(resourcePath)):
                     os.rmdir(resourcePath)
+                    resourcePath = os.path.dirname(resourcePath)
+                    if (resourceName in ("unix", "remote_profile") and 
+                        path.exists(resourcePath) and
+                        not listDirectory(resourcePath)):
+                        os.rmdir(resourcePath)
         return retRes
 
     def umountUserRes(self, umountPaths):
@@ -975,13 +983,6 @@ class Client(commandServer, encrypt, Desktop):
                                  *self.clVars.Get('cl_client_user_mount_name'))
         return True
     
-    def umountPath(self, upath):
-        if upath and not self.umountSleepPath(upath):
-            return False
-        if os.path.exists(upath):
-            os.rmdir(upath)
-        return True
-
     def getDefaultRunlevelDaemons(self):
         """
         Получить все службы из default уровня загрузки
