@@ -468,7 +468,8 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
                 "share", "share", path.join(self.Get('ur_home_path'), "Share"),
                 samba_host)
             yield (
-                "unix", "unix", path.join(home, ".%s" % self.Get('ur_login')),
+                "unix", "unix", path.join(home, ".%s" % self.Get('ur_login'),
+                                          "profile"),
                 samba_host)
             yield (
                 "homes", "homes", path.join(self.Get('ur_home_path'), "Home"),
@@ -480,7 +481,8 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
                 yield ("ftp", '', '', '')
             if self.Get('cl_replication_host'):
                 yield ("remote_profile", "unix",
-                       path.join(home, ".%s.remote" % self.Get('ur_login')),
+                       path.join(home, ".%s" % self.Get('ur_login'),
+                                 "remote_profile"),
                        self.Get('cl_replication_host'))
             else:
                 yield ("remote_profile", 'unix', '', '')
